@@ -62,7 +62,7 @@ class InstaClient(Scraper):
         return wrapper
     
     # INIT
-    def __init__(self, driver_type: int=CHROMEDRIVER, host_type:int=LOCAHOST, driver_path=None, init_driver=True, debug=False, error_callback=None, localhost_headless=False):
+    def __init__(self, driver_type: int=CHROMEDRIVER, host_type:int=LOCAHOST, driver_path=None, init_driver=False, debug=False, error_callback=None, localhost_headless=False):
         """
         Create an `InstaClient` object to access the instagram website.
 
@@ -93,7 +93,7 @@ class InstaClient(Scraper):
                 raise InvalidErrorCallbackError()
         self.error_callback = error_callback
         self.localhost_headless = localhost_headless
-        self.logger = get_logger()
+        self.logger = logging.getLogger(__name__)
         self.logged_in = False
         self.driver = None
         self.username = None
@@ -176,13 +176,9 @@ class InstaClient(Scraper):
             password_input.send_keys(password)
             time.sleep(1)
             self.logger.debug('INSTACLIENT: Filled in form')
-            if self.debug:
-                self.error_callback(self.driver)
             login_btn = self.__find_element(EC.presence_of_element_located((By.XPATH,Paths.LOGIN_BTN)), url=ClientUrls.LOGIN_URL)# login button xpath changes after text is entered, find first
             self.__press_button(login_btn)
             self.logger.debug('INSTACLIENT: Sent form')
-            if self.debug:
-                self.error_callback(self.driver)
         except ElementClickInterceptedException as error:
             self.password = None
             self.driver.get(ClientUrls.LOGIN_URL)
@@ -215,10 +211,10 @@ class InstaClient(Scraper):
         # Detect Suspicious Login Attempt Dialogue
         send_code = self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.SEND_CODE)))
         if send_code:
-            self.logger.debug('INSTACLIENT: Suspicious Login Attempt.')
+            self.logger.warn('INSTACLIENT: Suspicious Login Attempt.')
             send_code = self.__find_element(EC.presence_of_element_located((By.XPATH, Paths.SEND_CODE)), wait_time=4)
             self.__press_button(send_code)
-            self.logger.debug('INSTACLIENT: Sent Security Code')
+            self.logger.warn('INSTACLIENT: Sent Security Code')
             # Detect Error
             alert = self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.ERROR_SENDING_CODE)), wait_time=2)
             if alert:
@@ -227,7 +223,7 @@ class InstaClient(Scraper):
                 self.__press_button(email)
                 time.sleep(0.5)
                 self.__press_button(send_code)
-                self.logger.debug('INSTACLIENT: Sending code via email')
+                self.logger.warn('INSTACLIENT: Sending code via email')
                 raise SuspisciousLoginAttemptError(mode=SuspisciousLoginAttemptError.EMAIL)
             raise SuspisciousLoginAttemptError(mode=SuspisciousLoginAttemptError.PHONE)
 
@@ -235,16 +231,16 @@ class InstaClient(Scraper):
         scode_input = self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.VERIFICATION_CODE)))
         if scode_input:
             # 2F Auth is enabled, request security code
-            self.logger.debug('INSTACLIENT: 2FA Required. Check Auth App')
+            self.logger.warn('INSTACLIENT: 2FA Required. Check Auth App')
             raise VerificationCodeNecessary()
         else:
             self.logged_in = True
 
         self.logger.debug('INSTACLIENT: Credentials are Correct')
-        if self.debug:
-            self.error_callback(self.driver)
-        # Discard Driver or complete login
 
+        # Discard Driver or complete login
+        if discard_driver:
+            self.__discard_driver()
         else:
             # Detect and dismiss save info Dialog
             self.driver.get(ClientUrls.HOME_URL)
@@ -256,9 +252,6 @@ class InstaClient(Scraper):
             # Detect 'Turn On Notifications' Box
             if self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.DISMISS_DIALOGUE))):
                 self.__dismiss_dialogue()
-                
-            if self.debug:
-                self.error_callback(self.driver)
         return self.logged_in
 
 
@@ -292,7 +285,7 @@ class InstaClient(Scraper):
                 raise SuspisciousLoginAttemptError(mode)
             raise SuspisciousLoginAttemptError()
         else:
-            self.logger.debug('Wrong Url when resending code')
+            self.logger.warn('Wrong Url when resending code')
             return False
 
 
@@ -421,15 +414,13 @@ class InstaClient(Scraper):
         if self.driver.current_url != ClientUrls.NAV_USER.format(user):
             self.driver.get(ClientUrls.NAV_USER.format(user))
 
-        self.logger.debug('INSTACLIENT: Url: ', self.driver.current_url)
+        self.logger.debug('INSTACLIENT: Url: {}'.format(self.driver.current_url))
         if self.driver.current_url == ClientUrls.LOGIN_THEN_USER.format(user):
             raise NotLoggedInError()
         elif self.driver.current_url != ClientUrls.NAV_USER.format(user):
-            self.error_callback(self.driver)
             time.sleep(1)
             self.driver.get(ClientUrls.NAV_USER.format(user))
             time.sleep(1)
-            self.error_callback(self.driver)
 
 
         if self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.COOKIES_LINK))):
@@ -669,7 +660,7 @@ class InstaClient(Scraper):
             try:
                 self.driver.find_element_by_xpath("//*[@aria-label='{}']".format(action)).click()
             except Exception as e:
-                self.logger.debug(e)
+                self.logger.error(e)
 
             self.driver.find_elements_by_class_name('ckWGn')[0].click()
 
@@ -686,8 +677,6 @@ class InstaClient(Scraper):
         """
         # Navigate to User's dm page
         try:
-            if self.debug:
-                self.error_callback(self.driver)
             self.nav_user_dm(user)
             text_area = self.__find_element(EC.presence_of_element_located((By.XPATH, Paths.DM_TEXT_AREA)))
             text_area.send_keys(message)
@@ -697,7 +686,7 @@ class InstaClient(Scraper):
         except Exception as error: 
             if self.debug:
                 self.error_callback(self.driver)
-            self.logger.debug('INSTACLIENT: An error occured when sending a DM to the user <{}>'.format(user))
+            self.logger.error('INSTACLIENT: An error occured when sending a DM to the user <{}>'.format(user))
             raise error
 
 
@@ -956,7 +945,7 @@ class InstaClient(Scraper):
         """
         restriction = self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.RESTRICTION_DIALOG)), wait_time=1.2)
         if restriction:
-            self.logger.debug('INSTACLIENT: WARNING: ACCOUNT <{}> HAS BEEN RESTRICTED'.format(self.username))
+            self.logger.warn('INSTACLIENT: WARNING: ACCOUNT <{}> HAS BEEN RESTRICTED'.format(self.username))
             buttons = self.__find_element(EC.presence_of_element_located((By.XPATH, Paths.RESTRICTION_DIALOGUE_BTNS)), retry=False)
             buttons.click()
             time.sleep(randrange(2,4))
@@ -964,7 +953,7 @@ class InstaClient(Scraper):
 
         block = self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.BLOCK_DIV)), wait_time=1.2)
         if block:
-            self.logger.debug('INSTACLIENT: WARNING: ACCOUNT <{}> HAS BEEN BLOCKED - Log in Manually'.format(self.username))
+            self.logger.warn('INSTACLIENT: WARNING: ACCOUNT <{}> HAS BEEN BLOCKED - Log in Manually'.format(self.username))
             raise BlockedAccountError(self.username)
 
 
@@ -1021,4 +1010,4 @@ class InstaClient(Scraper):
             try:
                 self.login(self.username, self.password)
             except:
-                raise InstaClientError(message='Tried self.logger in when initiating driver, but username and password are not defined.') 
\ No newline at end of file
+                raise InstaClientError(message='Tried logging in when initiating driver, but username and password are not defined.') 
\ No newline at end of file
