@@ -30,12 +30,18 @@ class Paths:
     SEND_DM_BTN = '//div[@class="X3a-9"]//descendant::button'
     # Check Login Status Procedure
     NAV_BAR = '//div[@data-testid="mobile-nav-logged-in" and @class="BvyAW"]'
+    # ENGAGEMENT PROCEDURES
+    # Like Feed Posts
+    LIKE_BTN = ''
     # GENERAL
     COOKIES_LINK = '//a[contains(@heref, "cookies") or contains(text(), "Cookie")]'
     ACCEPT_COOKIES = '//button[@class="aOOlW  bIiDR  "]'
     SETTINGS_BTN = '//button[@class="Q46SR"]'
     BUTTON = '//button[text()="{}"]'
     NOT_NOW_BTN = '//button[@class="aOOlW   HoLwm "]'
+    RESTRICTION_DIALOG = '//div[@class="_7UhW9   xLCgt      MMzan   _0PwGv         uL8Hv         " and contains(text(), "restrict")]'
+    RESTRICTION_DIALOGUE_BTNS = '//div[@class="pbNvD  fPMEg    " and @role="dialog"]//descendant::button'
+    BLOCK_DIV = '//div[@class="_7UhW9    vy6Bb     MMzan  KV-D4          uL8Hv     l4b0S    " and contains(text(), "unusual activity")]'
     # SETTINGS OPTIONS
     LOG_OUT_BTN = '//a[@class="_34G9B H0ovd"]'
     CONFIRM_LOGOUT_BTN = '//button[@class="aOOlW  bIiDR  "]'
